@@ -6,9 +6,12 @@ import logging
 from collections.abc import Sequence
 from dataclasses import dataclass
 from pathlib import Path
+from typing import List, Literal
 
 import pkg_resources
 
+from mypy_boto3_builder.constants import PACKAGE_NAME, PROG_NAME
+
 
 def get_absolute_path(path: str) -> Path:
     """
@@ -34,13 +37,21 @@ class Namespace:
     service_names: list[str]
     build_version: str
     installed: bool
-    skip_master: bool
-    skip_services: bool
+    products: List[
+        Literal[
+            "boto3",
+            "boto3-services",
+            "boto3-docs",
+            "aiobotocore",
+            "aiobotocore-services",
+            "aiobotocore-docs",
+        ]
+    ]
     builder_version: str
-    generate_docs: bool
     list_services: bool
     partial_overload: bool
     skip_published: bool
+    disable_smart_version: bool
 
 
 def parse_args(args: Sequence[str]) -> Namespace:
@@ -51,11 +62,11 @@ def parse_args(args: Sequence[str]) -> Namespace:
         Argument parser.
     """
     try:
-        version = pkg_resources.get_distribution("mypy-boto3-builder").version
+        version = pkg_resources.get_distribution(PACKAGE_NAME).version
     except pkg_resources.DistributionNotFound:
         version = "0.0.0"
 
-    parser = argparse.ArgumentParser("mypy_boto3_builder", description="Builder for mypy-boto3.")
+    parser = argparse.ArgumentParser(PROG_NAME, description="Builder for mypy-boto3.")
     parser.add_argument("-d", "--debug", action="store_true", help="Show debug messages")
     parser.add_argument(
         "-b",
@@ -64,17 +75,28 @@ def parse_args(args: Sequence[str]) -> Namespace:
     )
     parser.add_argument("-V", "--version", action="version", version=version)
     parser.add_argument(
-        "--skip-master",
-        action="store_true",
-        help="Whether to skip master and stubs modules",
-    )
-    parser.add_argument(
-        "--skip-services", action="store_true", help="Whether to skip service modules"
+        "--product",
+        dest="products",
+        choices=[
+            "boto3",
+            "boto3-services",
+            "boto3-docs",
+            "aiobotocore",
+            "aiobotocore-services",
+            "aiobotocore-docs",
+        ],
+        nargs="+",
+        default=["boto3", "boto3-services"],
+        help="Select package to create annotations for",
     )
     parser.add_argument(
         "--skip-published", action="store_true", help="Skip packages that are already on PyPI"
     )
-    parser.add_argument("--docs", action="store_true", help="Generate docs for modules")
+    parser.add_argument(
+        "--no-smart-version",
+        action="store_true",
+        help="Disable version bump if package is already published",
+    )
     parser.add_argument(
         "--panic",
         action="store_true",
@@ -117,13 +139,12 @@ def parse_args(args: Sequence[str]) -> Namespace:
         log_level=logging.DEBUG if result.debug else logging.INFO,
         output_path=result.output_path,
         service_names=result.service_names,
-        skip_master=result.skip_master,
-        skip_services=result.skip_services,
+        products=result.products,
         build_version=result.build_version,
         installed=result.installed,
         builder_version=result.builder_version,
-        generate_docs=result.docs,
         list_services=result.list_services,
         partial_overload=result.partial_overload,
         skip_published=result.skip_published,
+        disable_smart_version=result.no_smart_version,
     )
